@@ -63,10 +63,10 @@ def streaming_post(i: ItemUrlFilter):
 
 
 @app.get("/api/streaming_get/")
-def streaming_get(md5_hex):
+async def streaming_get(md5_hex):
     dic = {'content-disposition': f"attachment; filename*=utf-8''all.csv.gz"}
     return StreamingResponse(it_streaming(dic_item_url_filter[md5_hex]), headers=dic)
 
 
-def server(host='0.0.0.0', int_port=20423):
+def server(host='0.0.0.0', int_port=20425):
     uvicorn.run("cameo_claw.streaming:app", host=host, port=int_port, reload=False, debug=False, workers=1)
